@@ -97,6 +97,7 @@ typedef struct {
  * CMML_List: A doubly linked list
  */
 typedef struct _CMML_List CMML_List;
+
 /**
  * USE THE DEFINED TYPE CMML_List FOR THIS!
  *
@@ -205,16 +206,16 @@ typedef struct {
  * either a head or a clip
  */
 typedef struct {
-  char *id;      /**< id attribute of link */
-  char *class;   /**< class attribute of link */
-  char *title;   /**< title attribute of link */
-  char *lang;    /**< language code of link */
-  char *dir;     /**< directionality of lang (ltr/rtl) */
-  char *href;    /**< href attribute of link */
-  char *type;    /**< type attribute of link */
-  char *rel;     /**< rel attribute of link */
-  char *rev;     /**< rev attribute of link */
-  char *media;   /**< media attribute of link */
+  char *id;         /**< id attribute of link */
+  char *link_class; /**< class attribute of link */
+  char *title;      /**< title attribute of link */
+  char *lang;       /**< language code of link */
+  char *dir;        /**< directionality of lang (ltr/rtl) */
+  char *href;       /**< href attribute of link */
+  char *type;       /**< type attribute of link */
+  char *rel;        /**< rel attribute of link */
+  char *rev;        /**< rev attribute of link */
+  char *media;      /**< media attribute of link */
 } CMML_LinkElement;
 
 /**
@@ -241,7 +242,7 @@ typedef struct {
  */
 typedef struct {
   char *clip_id;         /**< id attribute of clip */
-  char *class;           /**< class attribute of clip */
+  char *clip_class;      /**< class attribute of clip */
   char *title;           /**< title attribute of clip */
   char *lang;            /**< language attribute of desc element */
   char *dir;             /**< directionality of lang */
