@@ -156,7 +156,7 @@ cmml_clip_new (CMML_Time *start_time, CMML_Time *end_time)
   CMML_Clip * a;
   a = (CMML_Clip *) cmml_malloc(sizeof(CMML_Clip));
   a->clip_id      = NULL;
-  a->class        = NULL;
+  a->clip_class   = NULL;
   a->title        = NULL;
   a->lang         = NULL;
   a->dir          = NULL;
@@ -272,16 +272,16 @@ cmml_link_element_clone (CMML_LinkElement * link)
   /* maybe consider memcpy for speedup and introduce reference counting!
      memcpy (new_link, link, sizeof (*new_link));
   */
-  new_link->id      = cmml_strdup (link->id);
-  new_link->class   = cmml_strdup (link->class);
-  new_link->title   = cmml_strdup (link->title);
-  new_link->lang    = cmml_strdup (link->lang);
-  new_link->dir     = cmml_strdup (link->dir);
-  new_link->href    = cmml_strdup (link->href);
-  new_link->type    = cmml_strdup (link->type);
-  new_link->rel     = cmml_strdup (link->rel);
-  new_link->rev     = cmml_strdup (link->rev);
-  new_link->media   = cmml_strdup (link->media);
+  new_link->id         = cmml_strdup (link->id);
+  new_link->link_class = cmml_strdup (link->link_class);
+  new_link->title      = cmml_strdup (link->title);
+  new_link->lang       = cmml_strdup (link->lang);
+  new_link->dir        = cmml_strdup (link->dir);
+  new_link->href       = cmml_strdup (link->href);
+  new_link->type       = cmml_strdup (link->type);
+  new_link->rel        = cmml_strdup (link->rel);
+  new_link->rev        = cmml_strdup (link->rev);
+  new_link->media      = cmml_strdup (link->media);
   return new_link;
 }
 
@@ -388,7 +388,7 @@ cmml_clip_clone (CMML_Clip * src)
   memcpy (a, src, sizeof (*a));
   */
   a->clip_id    = cmml_strdup(src->clip_id);
-  a->class      = cmml_strdup(src->class);
+  a->clip_class = cmml_strdup(src->clip_class);
   a->title      = cmml_strdup(src->title);
   a->lang       = cmml_strdup(src->lang);
   a->dir        = cmml_strdup(src->dir);
@@ -471,7 +471,7 @@ cmml_link_element_destroy (CMML_LinkElement * link)
 {
   if (link == NULL) return NULL;
   cmml_free (link->id);
-  cmml_free (link->class);
+  cmml_free (link->link_class);
   cmml_free (link->title);
   cmml_free (link->lang);
   cmml_free (link->dir);
@@ -567,7 +567,7 @@ cmml_clip_destroy(CMML_Clip * a)
 {
   if (a == NULL) return;
   cmml_free(a->clip_id);
-  cmml_free(a->class);
+  cmml_free(a->clip_class);
   cmml_free(a->title);
   cmml_free(a->lang);
   cmml_free(a->dir);
@@ -743,7 +743,7 @@ int cmml_link_list_snprint (char *buf, int *_len, int *_n, int *_n_written,
 	
       BEGIN_TAG("link");
       APPEND_ATTRIBUTE("id", l->id);
-      APPEND_ATTRIBUTE("class", l->class);
+      APPEND_ATTRIBUTE("class", l->link_class);
       APPEND_ATTRIBUTE("title", l->title);
       APPEND_ATTRIBUTE("lang", l->lang);
       APPEND_ATTRIBUTE("dir", l->dir);
@@ -995,7 +995,7 @@ int cmml_clip_snprint(char *buf, int n, CMML_Clip * a)
   
   BEGIN_TAG("clip");
   APPEND_ATTRIBUTE("id", a->clip_id);
-  APPEND_ATTRIBUTE("class", a->class);
+  APPEND_ATTRIBUTE("class", a->clip_class);
   APPEND_ATTRIBUTE("title", a->title);
   APPEND_ATTRIBUTE("lang", a->lang);
   APPEND_ATTRIBUTE("dir", a->dir);
@@ -1061,7 +1061,7 @@ int cmml_clip_pretty_snprint(char *buf, int n, CMML_Clip * a)
   
   BEGIN_TAG("clip");
   APPEND_ATTRIBUTE("id", a->clip_id);
-  APPEND_ATTRIBUTE("class", a->class);
+  APPEND_ATTRIBUTE("class", a->clip_class);
   APPEND_ATTRIBUTE("title", a->title);
   APPEND_ATTRIBUTE("lang", a->lang);
   APPEND_ATTRIBUTE("dir", a->dir);
