@@ -481,7 +481,7 @@ insert_link_tag(CMML_List * link_list, const XML_Char **attr, CMML_Context *ctxt
   if ((l = (CMML_LinkElement *) cmml_malloc(sizeof(CMML_LinkElement)))
       == NULL) return NULL;
   l->id = NULL;
-  l->class = NULL;
+  l->link_class = NULL;
   l->title = NULL;
   l->lang = NULL;
   l->dir = NULL;
@@ -498,7 +498,7 @@ insert_link_tag(CMML_List * link_list, const XML_Char **attr, CMML_Context *ctxt
     if (cmml_strcmp(attr[i], "id") == 0) {
       l->id = cmml_strdup(attr[i+1]);
     } else if (cmml_strcmp(attr[i], "class") == 0) {
-      l->class = cmml_strdup(attr[i+1]);
+      l->link_class = cmml_strdup(attr[i+1]);
     } else if (cmml_strcmp(attr[i], "title") == 0) {
       l->title = cmml_strdup(attr[i+1]);
     } else if (cmml_strcmp(attr[i], "lang") == 0) {
@@ -544,7 +544,7 @@ insert_clip_attrs(CMML_Clip * a, const XML_Char **attr, CMML_Context * ctxt)
     if (cmml_strcmp(attr[i], "id") == 0) {
       a->clip_id = cmml_strdup(attr[i+1]);
     } else if (cmml_strcmp(attr[i], "class") == 0) {
-      a->class = cmml_strdup(attr[i+1]);
+      a->clip_class = cmml_strdup(attr[i+1]);
     } else if (cmml_strcmp(attr[i], "title") == 0) {
       a->title = cmml_strdup(attr[i+1]);
     } else if (cmml_strcmp(attr[i], "lang") == 0) {
